==> ludia-1.3.0.tar.gz: ludia-1.3.0/uninstall_pgsenna2.sql <==
DROP OPERATOR CLASS text_ops USING fulltext CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextb CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextu CASCADE;
DROP OPERATOR CLASS text_ops USING fulltexta CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextab CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextau CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextr CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextrb CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextru CASCADE;

DROP OPERATOR @@ (TEXT, TEXT);
DROP OPERATOR @@ (_TEXT, TEXT);
DROP OPERATOR @@ (TEXT, _TEXT);

DELETE FROM pg_am WHERE amname LIKE 'fulltext%';

DROP FUNCTION pgs2insert(TEXT, TEXT);
DROP FUNCTION _pgs2insert(TEXT, TEXT);
DROP FUNCTION pgs2beginscan(TEXT, TEXT);
DROP FUNCTION pgs2gettuple(TEXT, TEXT);
DROP FUNCTION pgs2getmulti(TEXT, TEXT);
DROP FUNCTION pgs2rescan(TEXT, TEXT);
DROP FUNCTION pgs2endscan(TEXT, TEXT);
DROP FUNCTION pgs2markpos(TEXT, TEXT);
DROP FUNCTION pgs2restrpos(TEXT, TEXT);
DROP FUNCTION pgs2build(TEXT, TEXT);
DROP FUNCTION pgs2buildb(TEXT, TEXT);
DROP FUNCTION pgs2buildu(TEXT, TEXT);
DROP FUNCTION _pgs2build(TEXT, TEXT);
DROP FUNCTION _pgs2buildb(TEXT, TEXT);
DROP FUNCTION _pgs2buildu(TEXT, TEXT);
DROP FUNCTION pgs2bulkdelete(TEXT, TEXT);
DROP FUNCTION _pgs2bulkdelete(TEXT, TEXT);
DROP FUNCTION pgs2vacuumcleanup(INTERNAL, INTERNAL);
DROP FUNCTION pgs2costestimate(TEXT, TEXT);
DROP FUNCTION pgs2contain(TEXT, TEXT);
DROP FUNCTION _pgs2contain(_TEXT, TEXT);
DROP FUNCTION pgs2nop(TEXT);
DROP FUNCTION pgs2getscore(tid, TEXT);
DROP FUNCTION pgs2getscore(tid);
DROP FUNCTION pgs2getnhits();
DROP FUNCTION pgs2options();
DROP FUNCTION pgs2indexcache();
DROP FUNCTION pgs2destroy();
DROP FUNCTION pgs2indexinfo();
DROP FUNCTION pgs2indexinfodb();
DROP FUNCTION pgs2getlexicon(TEXT);
DROP FUNCTION pgs2version();
DROP FUNCTION pgs2seninfo();
DROP FUNCTION pgs2getoption();
DROP FUNCTION pgs2pdftotext1(TEXT);
DROP FUNCTION pgs2pdftotext2(BYTEA);
DROP FUNCTION pgs2snippet1(INT, INT, INT, TEXT, TEXT, INT, TEXT, TEXT);
DROP FUNCTION pgs2recovery();
DROP FUNCTION pgs2textporter1(TEXT);
DROP FUNCTION pgs2textporter2(BYTEA);

==> ludia-1.5.0.tar.gz: ludia-1.5.0/uninstall_pgsenna2.sql <==
DROP OPERATOR CLASS text_ops USING fulltext CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextb CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextu CASCADE;
DROP OPERATOR CLASS text_ops USING fulltexta CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextab CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextau CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextr CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextrb CASCADE;
DROP OPERATOR CLASS text_ops USING fulltextru CASCADE;

DROP OPERATOR @@ (TEXT, TEXT);
DROP OPERATOR @@ (_TEXT, TEXT);
DROP OPERATOR @@ (TEXT, _TEXT);

DELETE FROM pg_am WHERE amname LIKE 'fulltext%';

DROP FUNCTION pgs2insert(TEXT, TEXT);
DROP FUNCTION _pgs2insert(TEXT, TEXT);
DROP FUNCTION pgs2beginscan(TEXT, TEXT);
DROP FUNCTION pgs2gettuple(TEXT, TEXT);
DROP FUNCTION pgs2getmulti(TEXT, TEXT);
DROP FUNCTION pgs2rescan(TEXT, TEXT);
DROP FUNCTION pgs2endscan(TEXT, TEXT);
DROP FUNCTION pgs2markpos(TEXT, TEXT);
DROP FUNCTION pgs2restrpos(TEXT, TEXT);
DROP FUNCTION pgs2build(TEXT, TEXT);
DROP FUNCTION pgs2buildb(TEXT, TEXT);
DROP FUNCTION pgs2buildu(TEXT, TEXT);
DROP FUNCTION _pgs2build(TEXT, TEXT);
DROP FUNCTION _pgs2buildb(TEXT, TEXT);
DROP FUNCTION _pgs2buildu(TEXT, TEXT);
DROP FUNCTION pgs2bulkdelete(TEXT, TEXT);
DROP FUNCTION _pgs2bulkdelete(TEXT, TEXT);
DROP FUNCTION pgs2vacuumcleanup(INTERNAL, INTERNAL);
DROP FUNCTION pgs2costestimate(TEXT, TEXT);
DROP FUNCTION pgs2contain(TEXT, TEXT);
DROP FUNCTION _pgs2contain(_TEXT, TEXT);
DROP FUNCTION pgs2nop(TEXT);
DROP FUNCTION pgs2getscore(tid, TEXT);
DROP FUNCTION pgs2getscore(tid);
DROP FUNCTION pgs2getnhits();
DROP FUNCTION pgs2options();
DROP FUNCTION pgs2indexcache();
DROP FUNCTION pgs2destroy();
DROP FUNCTION pgs2indexinfo();
DROP FUNCTION pgs2indexinfodb();
DROP FUNCTION pgs2getlexicon(TEXT);
DROP FUNCTION pgs2version();
DROP FUNCTION pgs2seninfo();
DROP FUNCTION pgs2getoption();
DROP FUNCTION pgs2pdftotext1(TEXT);
DROP FUNCTION pgs2pdftotext2(BYTEA);
DROP FUNCTION pgs2snippet1(INT, INT, INT, TEXT, TEXT, INT, TEXT, TEXT);
DROP FUNCTION pgs2norm(TEXT, INT);
DROP FUNCTION pgs2recovery();
DROP FUNCTION pgs2lock(OID);
DROP FUNCTION pgs2unlock(OID);
DROP FUNCTION pgs2fsync();
DROP FUNCTION pgs2lock();
DROP FUNCTION pgs2unlock();
DROP FUNCTION pgs2textporter1(TEXT);
DROP FUNCTION pgs2textporter2(BYTEA);
